@@ -28,6 +28,10 @@
 #include <errno.h>
 #include <string.h>
 
+#ifndef SOL_NETLINK
+#define SOL_NETLINK	270
+#endif
+
 void process_netlink_msg(int sock)
 {
 	int len;
@@ -70,12 +74,16 @@ void process_netlink_msg(int sock)
 int netlink_socket(void)
 {
 	int rc, sock;
+	unsigned int val = 1;
 	struct sockaddr_nl snl;
 
 	sock = socket(PF_NETLINK, SOCK_RAW, NETLINK_ROUTE);
 	if (sock == -1) {
 		flog(LOG_ERR, "Unable to open netlink socket: %s", strerror(errno));
 	}
+	else if (setsockopt(sock, SOL_NETLINK, NETLINK_NO_ENOBUFS, &val, sizeof(val)) < 0 ) {
+		flog(LOG_ERR, "Unable to setsockopt NETLINK_NO_ENOBUFS: %s", strerror(errno));
+	}
 
 	memset(&snl, 0, sizeof(snl));
 	snl.nl_family = AF_NETLINK;
